.. _bibliography-page:

==============
 Bibliography
==============

Related articles
----------------

This `blog page <https://www.fabrice-salvaire.fr/en/blog/first-steps-with-spice>`_ was the genesis
of PySpice and gives an introduction to SPICE and explain how to plug *ngspice* to Python.

SPICE References
----------------

The `technical report No. UCB/ERL M520 <http://www.eecs.berkeley.edu/Pubs/TechRpts/1975/9602.html>`_
written by Nagel gives an interesting description of the algorithms involved in Spice. I recommend
to read part 2 and 3 that explain the equation formulation. The next parts describes the
numerical analysis.

The relevant references on Spice are by date of publication:

 * `Technical Report No. UCB/ERL M382 <http://www.eecs.berkeley.edu/Pubs/TechRpts/1973/22871.html>`_;
   SPICE (Simulation Program with Integrated Circuit Emphasis);
   Nagel, Laurence W. and Pederson, D.O.;
   April 1973

 * `Technical Report No. UCB/ERL M520 <http://www.eecs.berkeley.edu/Pubs/TechRpts/1975/9602.html>`_;
   SPICE2: A Computer Program to Simulate Semiconductor Circuits;
   Nagel, Laurence W.;
   1975

 * `Technical Report No. UCB/ERL M89/42 <http://www.eecs.berkeley.edu/Pubs/TechRpts/1989/1216.html>`_;
   Analysis of Performance and Convergence Issues for Circuit Simulation;
   Quarles, Thomas L.;
   1989

 * `official spice3f5 source code <http://embedded.eecs.berkeley.edu/pubs/downloads/spice/index.htm>`_
   on eecs.berkeley.edu server, the page contains some links on Spice (historical notes).

.. End
